PyLucene.Document

PyLucene :: Document :: Class Document |
[hide private]
[frames] | no frames]

# Class Document

j_document objects

Instance Methods | [hide private]
__delattr__(...) x.__delattr__('name') <==> del x.name |
__getattr__(...) |
__getitem__(x, y) x[y] |
__init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__iter__(x) iter(x) |
__len__(x) len(x) |
add(...) |
fields(...) |
get(...) |
getBinaryValue(...) |
getBinaryValues(...) |
getBoost(...) |
getField(...) |
getFields(...) |
getValues(...) |
removeField(...) |
removeFields(...) |
setBoost(...) |
Inherited from `Object`: `__eq__`, `__ge__`, `__gt__`, `__hash__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__str__`, `equals`, `getClass`, `hashCode`, `notify`, `notifyAll`, `toString`, `wait` Inherited from `object`: `__getattribute__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __delattr__(...) |
x.__delattr__('name') <==> del x.name Overrides: object.__delattr__

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Object.__init__